#define _GNU_SOURCE
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <limits.h>
#include <errno.h>

#include "uhumenu.h"

char *plugin_name = "BlackBox";

static void indent (FILE *f, int n)
{
	int i;
	for (i = 0; i < n; i++) fprintf(f, "\t");
}

static void dump (FILE *f, const struct menu *menu, const char *lang, int n)
{
	int i;
	for (i = 0; i < menu->nr; i++) {
		if (!menu->items[i].issubmenu) {
			indent(f, n);
			fprintf(f, "[exec] (%s) {%s%s}\n",
			  get_value_8bit(&menu->items[i], NULL, "Name", lang),
			  menu->items[i].terminal ? "xterm -e " : "",
			  get_value(&menu->items[i], NULL, "Exec", lang));
		} else {
			indent(f, n);
			fprintf(f, "[submenu] (%s)\n",
			  get_value_8bit(&menu->items[i], NULL, "Name", lang));
			dump(f, menu->items[i].submenu, lang, n+1);
			indent(f, n);
			fprintf(f, "[end]\n");
		}
	}
}

int write_menu_lang (const struct menu *menu, const char *path,
  const struct language *language)
{
	char *lang;
	char file[PATH_MAX];
	FILE *f;

	lang = language->name;
	if (lang[0] == '\0') lang = "C";
	sprintf(file, "%s/%s", path, lang);
	if ((f = fopen(file, "w")) == NULL) {
		fprintf(stderr, "blackbox: fopen %s: %s\n", file, strerror(errno));
		return -1;
	}
	if (menu->nr > 0) dump(f, menu->items[0].submenu, lang, 0);
	fclose(f);
	return 0;
}

