#define _GNU_SOURCE
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <limits.h>
#include <errno.h>

#include "uhumenu.h"

char *plugin_name = "WindowMaker";

static char value[500];

static char *wmaker_get_value (struct item *item, const char *section,
  const char *key, const char *lang)
{
	char *v1 = get_value(item, section, key, lang);
	char *v2 = value;
	if (v1 == NULL) return NULL;
	do {
		if (*v1 != '"') *v2++ = *v1;
	} while (*v1++);
	return value;
}

static void indent (FILE *f, int n)
{
	int i;
	for (i = 0; i < n; i++) fprintf(f, " ");
}

static void dump (FILE *f, const struct menu *menu, const char *lang, int n)
{
	int i;
	for (i = 0; i < menu->nr; i++) {
		if (!menu->items[i].issubmenu) {
			indent(f, n);
			fprintf(f, "(\"%s\", EXEC, \"%s%s\")",
			  get_value_8bit(&menu->items[i], NULL, "Name", lang),
			  menu->items[i].terminal ? "xterm -e " : "",
			  wmaker_get_value(&menu->items[i], NULL, "Exec", lang));
		} else {
			indent(f, n);
			fprintf(f, "(\"%s\",\n",
			  get_value_8bit(&menu->items[i], NULL, "Name", lang));
			dump(f, menu->items[i].submenu, lang, n+1);
			indent(f, n);
			fprintf(f, ")");
		}
		if (i != menu->nr - 1) fprintf(f, ",");
		fprintf(f, "\n");
	}
}

int write_menu_lang (const struct menu *menu, const char *path,
  const struct language *language)
{
	char *lang;
	char file[PATH_MAX];
	FILE *f;

	lang = language->name;
	if (lang[0] == '\0') lang = "C";
	sprintf(file, "%s/%s", path, lang);
	if ((f = fopen(file, "w")) == NULL) {
		fprintf(stderr, "windowmaker: fopen %s: %s\n", file, strerror(errno));
		return -1;
	}
	dump(f, menu, lang, 0);
	fclose(f);
	return 0;
}

